@@ -4,8 +4,8 @@ use crate::actor;
 use crate::actor::*;
 use crate::event::*;
 use crate::gossip::sharded_gossip::BandwidthThrottles;
-use crate::metrics::KitsuneMetrics;
 use crate::types::gossip::GossipModuleType;
+use crate::types::metrics::KitsuneMetrics;
 use crate::*;
 use futures::future::FutureExt;
 use futures::stream::StreamExt;
