@@ -1,3 +1,4 @@
+use crate::metrics::*;
 use crate::types::*;
 use kitsune_p2p_types::config::*;
 use kitsune_p2p_types::tx2::tx2_api::*;
@@ -75,6 +76,7 @@ pub trait AsGossipModuleFactory: 'static + Send + Sync {
         space: Arc<KitsuneSpace>,
         ep_hnd: Tx2EpHnd<wire::Wire>,
         evt_sender: futures::channel::mpsc::Sender<event::KitsuneP2pEvent>,
+        metrics: Metrics,
     ) -> GossipModule;
 }
 
@@ -87,8 +89,9 @@ impl GossipModuleFactory {
         space: Arc<KitsuneSpace>,
         ep_hnd: Tx2EpHnd<wire::Wire>,
         evt_sender: futures::channel::mpsc::Sender<event::KitsuneP2pEvent>,
+        metrics: Metrics,
     ) -> GossipModule {
         self.0
-            .spawn_gossip_task(tuning_params, space, ep_hnd, evt_sender)
+            .spawn_gossip_task(tuning_params, space, ep_hnd, evt_sender, metrics)
     }
 }
